@@ -1,5 +1,5 @@
 
-from .fields import Field
+from . import fields
 from .meta import Meta
 
 
@@ -23,7 +23,7 @@ class MetaSerialiser(type):
 
         declared_fields = {}
         for field_name, field in attrs.items():
-            if isinstance(field, Field):
+            if isinstance(field, fields.Field):
                 declared_fields[field_name] = attrs.pop(field_name)
 
         attrs['_fields'].update(declared_fields)
@@ -53,26 +53,37 @@ class Serialiser(object):
             for obj in iter(obj_list)
         ]
 
-    def inflate_object(self, data, obj=None, **kwargs):
-        if obj is None:
-            # For now, we create a dummy object to hold the values
-            obj = object()
+    def inflate_object(self, data, instance=None, **kwargs):
+        obj = {}
         for name, field in self._fields.items():
             if field.readonly:
                 continue
             method = getattr(self, 'inflate_%s' % name, None)
             if method is not None:
-                method(data=data, obj=obj, **kwargs)
+                obj[name] = method(data=data, obj=obj, instance=instance, **kwargs)
             else:
                 field.inflate(name, data, obj, **kwargs)
-        return obj
+        return self.restore_object(obj, instance=instance, **kwargs)
 
     def inflate_list(self, data_list, **kwargs):
+        # XXX target object list?
         return [
             self.inflate_object(data, **kwargs)
             for data in data_list
         ]
 
+    def restore_object(self, obj, data, **kwargs):
+        raise NotImplementedError
+
+FIELD_MAP = {}
+# Auto-construct the field map
+for f in dir(fields):
+    cls = getattr(fields, f)
+    try:
+        if issubclass(cls, fields.Field):
+            FIELD_MAP[f] = cls
+    except TypeError:
+        pass
 
 class MetaModelSerialiser(MetaSerialiser):
     def __new__(cls, name, bases, attrs):
@@ -103,7 +114,8 @@ class MetaModelSerialiser(MetaSerialiser):
                     'default': f.default,
                 }
 
-                new_class._fields[f.name] = Field(**kwargs)
+                field_class = FIELD_MAP.get(f.__class__.__name__, fields.Field)
+                new_class._fields[f.name] = field_class(**kwargs)
         except AttributeError:
             pass
 
@@ -113,4 +125,12 @@ class MetaModelSerialiser(MetaSerialiser):
 class ModelSerialiser(Serialiser):
     __metaclass__ = MetaModelSerialiser
 
-    # XXX How to create a new instance?
+    def restore_object(self, obj, instance, **kwargs):
+        if instance:
+            for k, v in data.items():
+                setattr(instance, k, v)
+        else:
+            instance = self._meta.model(**data)
+        if kwargs.get('commit', True):
+            instance.save()
+        return instance
